==> echogem-0.1.0.tar.gz: echogem-0.1.0/echogem/legacy/06_experimental_cli.py <==
# Legacy: Experimental CLI Approaches (v0.1.0-rc4)
# Different command-line interface implementations tested
# Replaced by current argparse-based CLI in v0.2.0

import sys
import os
from typing import Dict, List, Optional
import click
import fire
import argparse

class ClickBasedCLI:
    """Click-based CLI - elegant but complex for simple use cases"""
    
    @click.group()
    def cli():
        """EchoGem - Transcript Processing and Q&A"""
        pass
    
    @cli.command()
    @click.argument('file', type=click.Path(exists=True))
    @click.option('--chunk-size', default=1000, help='Chunk size in characters')
    @click.option('--overlap', default=100, help='Overlap between chunks')
    def process(file, chunk_size, overlap):
        """Process a transcript file"""
        click.echo(f"Processing {file} with chunk size {chunk_size}")
        # Implementation would go here
    
    @cli.command()
    @click.argument('query')
    @click.option('--top-k', default=5, help='Number of results to return')
    def query(query, top_k):
        """Query the processed transcripts"""
        click.echo(f"Querying: {query}")
        # Implementation would go here

class FireBasedCLI:
    """Google Fire-based CLI - automatic but less control"""
    
    def process(self, file: str, chunk_size: int = 1000, overlap: int = 100):
        """Process a transcript file"""
        print(f"Processing {file} with chunk size {chunk_size}")
        # Implementation would go here
    
    def query(self, query: str, top_k: int = 5):
        """Query the processed transcripts"""
        print(f"Querying: {query}")
        # Implementation would go here
    
    def list_chunks(self):
        """List all available chunks"""
        print("Available chunks:")
        # Implementation would go here

class SimpleCLI:
    """Simple manual CLI parsing - basic but flexible"""
    
    def __init__(self):
        self.commands = {
            'process': self.process_file,
            'query': self.query_chunks,
            'list': self.list_chunks,
            'help': self.show_help
        }
    
    def run(self):
        """Main CLI loop"""
        if len(sys.argv) < 2:
            self.show_help()
            return
        
        command = sys.argv[1].lower()
        args = sys.argv[2:]
        
        if command in self.commands:
            self.commands[command](args)
        else:
            print(f"Unknown command: {command}")
            self.show_help()
    
    def process_file(self, args):
        """Process a transcript file"""
        if not args:
            print("Usage: echogem process <filename> [options]")
            return
        
        filename = args[0]
        chunk_size = 1000
        overlap = 100
        
        # Parse options
        for i, arg in enumerate(args[1:], 1):
            if arg == '--chunk-size' and i + 1 < len(args):
                chunk_size = int(args[i + 1])
            elif arg == '--overlap' and i + 1 < len(args):
                overlap = int(args[i + 1])
        
        print(f"Processing {filename} with chunk size {chunk_size}")
        # Implementation would go here
    
    def query_chunks(self, args):
        """Query the processed chunks"""
        if not args:
            print("Usage: echogem query <question> [options]")
            return
        
        question = ' '.join(args)
        top_k = 5
        
        # Parse options
        for i, arg in enumerate(args):
            if arg == '--top-k' and i + 1 < len(args):
                top_k = int(args[i + 1])
        
        print(f"Querying: {question}")
        # Implementation would go here
    
    def list_chunks(self, args):
        """List available chunks"""
        print("Available chunks:")
        # Implementation would go here
    
    def show_help(self):
        """Show help information"""
        print("EchoGem - Transcript Processing and Q&A")
        print("\nCommands:")
        print("  process <file>     Process a transcript file")
        print("  query <question>   Query the processed chunks")
        print("  list               List available chunks")
        print("  help               Show this help")

class ConfigBasedCLI:
    """Configuration-driven CLI - flexible but complex setup"""
    
    def __init__(self, config_file: str = "echogem.conf"):
        self.config = self.load_config(config_file)
        self.commands = self.config.get('commands', {})
    
    def load_config(self, config_file: str) -> Dict:
        """Load CLI configuration from file"""
        if not os.path.exists(config_file):
            return self.get_default_config()
        
        # Simple config format: key=value
        config = {}
        with open(config_file, 'r') as f:
            for line in f:
                line = line.strip()
                if line and not line.startswith('#'):
                    if '=' in line:
                        key, value = line.split('=', 1)
                        config[key.strip()] = value.strip()
        
        return config
    
    def get_default_config(self) -> Dict:
        """Get default CLI configuration"""
        return {
            'commands': {
                'process': {
                    'description': 'Process transcript file',
                    'options': ['--chunk-size', '--overlap']
                },
                'query': {
                    'description': 'Query processed chunks',
                    'options': ['--top-k', '--show-chunks']
                }
            }
        }
    
    def run(self):
        """Run the CLI based on configuration"""
        if len(sys.argv) < 2:
            self.show_help()
            return
        
        command = sys.argv[1]
        if command in self.commands:
            self.execute_command(command, sys.argv[2:])
        else:
            print(f"Unknown command: {command}")
            self.show_help()
    
    def execute_command(self, command: str, args: List[str]):
        """Execute a configured command"""
        cmd_config = self.commands[command]
        print(f"Executing {command}: {cmd_config['description']}")
        # Implementation would go here

class InteractiveCLI:
    """Interactive CLI with menu system"""
    
    def __init__(self):
        self.running = True
        self.commands = {
            '1': ('Process Transcript', self.process_transcript),
            '2': ('Query Chunks', self.query_chunks),
            '3': ('List Chunks', self.list_chunks),
            '4': ('Settings', self.show_settings),
            '5': ('Help', self.show_help),
            '6': ('Exit', self.exit_cli)
        }
    
    def run(self):
        """Main interactive loop"""
        while self.running:
            self.show_menu()
            choice = input("\nEnter your choice (1-6): ").strip()
            
            if choice in self.commands:
                self.commands[choice][1]()
            else:
                print("Invalid choice. Please try again.")
    
    def show_menu(self):
        """Display the main menu"""
        print("\n" + "="*50)
        print("           EchoGem CLI")
        print("="*50)
        for key, (name, _) in self.commands.items():
            print(f"{key}. {name}")
        print("="*50)
    
    def process_transcript(self):
        """Interactive transcript processing"""
        filename = input("Enter transcript filename: ").strip()
        if filename:
            print(f"Processing {filename}...")
            # Implementation would go here
        else:
            print("No filename provided.")
    
    def query_chunks(self):
        """Interactive querying"""
        question = input("Enter your question: ").strip()
        if question:
            print(f"Querying: {question}")
            # Implementation would go here
        else:
            print("No question provided.")
    
    def list_chunks(self):
        """List available chunks"""
        print("Available chunks:")
        # Implementation would go here
    
    def show_settings(self):
        """Show current settings"""
        print("Current settings:")
        # Implementation would go here
    
    def show_help(self):
        """Show help information"""
        print("EchoGem Help:")
        print("- Process transcripts to create searchable chunks")
        print("- Query chunks to get answers from your content")
        print("- Use settings to customize behavior")
    
    def exit_cli(self):
        """Exit the CLI"""
        print("Goodbye!")
        self.running = False

# TESTING RESULTS:
# - Click: Elegant but overkill for simple CLI
# - Fire: Automatic but less control over interface
# - Simple: Basic but requires manual parsing
# - Config: Flexible but complex setup
# - Interactive: User-friendly but not scriptable

# REPLACED BY: Current argparse-based CLI for balance of features and simplicity

==> echogem-0.1.3.tar.gz: echogem-0.1.3/echogem/legacy/06_experimental_cli.py <==
# Legacy: Experimental CLI Approaches (v0.1.0-rc4)
# Different command-line interface implementations tested
# Replaced by current argparse-based CLI in v0.2.0

import sys
import os
from typing import Dict, List, Optional
import click
import fire
import argparse

class ClickBasedCLI:
    """Click-based CLI - elegant but complex for simple use cases"""
    
    @click.group()
    def cli():
        """EchoGem - Transcript Processing and Q&A"""
        pass
    
    @cli.command()
    @click.argument('file', type=click.Path(exists=True))
    @click.option('--chunk-size', default=1000, help='Chunk size in characters')
    @click.option('--overlap', default=100, help='Overlap between chunks')
    def process(file, chunk_size, overlap):
        """Process a transcript file"""
        click.echo(f"Processing {file} with chunk size {chunk_size}")
        # Implementation would go here
    
    @cli.command()
    @click.argument('query')
    @click.option('--top-k', default=5, help='Number of results to return')
    def query(query, top_k):
        """Query the processed transcripts"""
        click.echo(f"Querying: {query}")
        # Implementation would go here

class FireBasedCLI:
    """Google Fire-based CLI - automatic but less control"""
    
    def process(self, file: str, chunk_size: int = 1000, overlap: int = 100):
        """Process a transcript file"""
        print(f"Processing {file} with chunk size {chunk_size}")
        # Implementation would go here
    
    def query(self, query: str, top_k: int = 5):
        """Query the processed transcripts"""
        print(f"Querying: {query}")
        # Implementation would go here
    
    def list_chunks(self):
        """List all available chunks"""
        print("Available chunks:")
        # Implementation would go here

class SimpleCLI:
    """Simple manual CLI parsing - basic but flexible"""
    
    def __init__(self):
        self.commands = {
            'process': self.process_file,
            'query': self.query_chunks,
            'list': self.list_chunks,
            'help': self.show_help
        }
    
    def run(self):
        """Main CLI loop"""
        if len(sys.argv) < 2:
            self.show_help()
            return
        
        command = sys.argv[1].lower()
        args = sys.argv[2:]
        
        if command in self.commands:
            self.commands[command](args)
        else:
            print(f"Unknown command: {command}")
            self.show_help()
    
    def process_file(self, args):
        """Process a transcript file"""
        if not args:
            print("Usage: py -m echogem.cli process <filename> [options]")
            return
        
        filename = args[0]
        chunk_size = 1000
        overlap = 100
        
        # Parse options
        for i, arg in enumerate(args[1:], 1):
            if arg == '--chunk-size' and i + 1 < len(args):
                chunk_size = int(args[i + 1])
            elif arg == '--overlap' and i + 1 < len(args):
                overlap = int(args[i + 1])
        
        print(f"Processing {filename} with chunk size {chunk_size}")
        # Implementation would go here
    
    def query_chunks(self, args):
        """Query the processed chunks"""
        if not args:
            print("Usage: echogem query <question> [options]")
            return
        
        question = ' '.join(args)
        top_k = 5
        
        # Parse options
        for i, arg in enumerate(args):
            if arg == '--top-k' and i + 1 < len(args):
                top_k = int(args[i + 1])
        
        print(f"Querying: {question}")
        # Implementation would go here
    
    def list_chunks(self, args):
        """List available chunks"""
        print("Available chunks:")
        # Implementation would go here
    
    def show_help(self):
        """Show help information"""
        print("EchoGem - Transcript Processing and Q&A")
        print("\nCommands:")
        print("  process <file>     Process a transcript file")
        print("  query <question>   Query the processed chunks")
        print("  list               List available chunks")
        print("  help               Show this help")

class ConfigBasedCLI:
    """Configuration-driven CLI - flexible but complex setup"""
    
    def __init__(self, config_file: str = "echogem.conf"):
        self.config = self.load_config(config_file)
        self.commands = self.config.get('commands', {})
    
    def load_config(self, config_file: str) -> Dict:
        """Load CLI configuration from file"""
        if not os.path.exists(config_file):
            return self.get_default_config()
        
        # Simple config format: key=value
        config = {}
        with open(config_file, 'r') as f:
            for line in f:
                line = line.strip()
                if line and not line.startswith('#'):
                    if '=' in line:
                        key, value = line.split('=', 1)
                        config[key.strip()] = value.strip()
        
        return config
    
    def get_default_config(self) -> Dict:
        """Get default CLI configuration"""
        return {
            'commands': {
                'process': {
                    'description': 'Process transcript file',
                    'options': ['--chunk-size', '--overlap']
                },
                'query': {
                    'description': 'Query processed chunks',
                    'options': ['--top-k', '--show-chunks']
                }
            }
        }
    
    def run(self):
        """Run the CLI based on configuration"""
        if len(sys.argv) < 2:
            self.show_help()
            return
        
        command = sys.argv[1]
        if command in self.commands:
            self.execute_command(command, sys.argv[2:])
        else:
            print(f"Unknown command: {command}")
            self.show_help()
    
    def execute_command(self, command: str, args: List[str]):
        """Execute a configured command"""
        cmd_config = self.commands[command]
        print(f"Executing {command}: {cmd_config['description']}")
        # Implementation would go here

class InteractiveCLI:
    """Interactive CLI with menu system"""
    
    def __init__(self):
        self.running = True
        self.commands = {
            '1': ('Process Transcript', self.process_transcript),
            '2': ('Query Chunks', self.query_chunks),
            '3': ('List Chunks', self.list_chunks),
            '4': ('Settings', self.show_settings),
            '5': ('Help', self.show_help),
            '6': ('Exit', self.exit_cli)
        }
    
    def run(self):
        """Main interactive loop"""
        while self.running:
            self.show_menu()
            choice = input("\nEnter your choice (1-6): ").strip()
            
            if choice in self.commands:
                self.commands[choice][1]()
            else:
                print("Invalid choice. Please try again.")
    
    def show_menu(self):
        """Display the main menu"""
        print("\n" + "="*50)
        print("           EchoGem CLI")
        print("="*50)
        for key, (name, _) in self.commands.items():
            print(f"{key}. {name}")
        print("="*50)
    
    def process_transcript(self):
        """Interactive transcript processing"""
        filename = input("Enter transcript filename: ").strip()
        if filename:
            print(f"Processing {filename}...")
            # Implementation would go here
        else:
            print("No filename provided.")
    
    def query_chunks(self):
        """Interactive querying"""
        question = input("Enter your question: ").strip()
        if question:
            print(f"Querying: {question}")
            # Implementation would go here
        else:
            print("No question provided.")
    
    def list_chunks(self):
        """List available chunks"""
        print("Available chunks:")
        # Implementation would go here
    
    def show_settings(self):
        """Show current settings"""
        print("Current settings:")
        # Implementation would go here
    
    def show_help(self):
        """Show help information"""
        print("EchoGem Help:")
        print("- Process transcripts to create searchable chunks")
        print("- Query chunks to get answers from your content")
        print("- Use settings to customize behavior")
    
    def exit_cli(self):
        """Exit the CLI"""
        print("Goodbye!")
        self.running = False

# TESTING RESULTS:
# - Click: Elegant but overkill for simple CLI
# - Fire: Automatic but less control over interface
# - Simple: Basic but requires manual parsing
# - Config: Flexible but complex setup
# - Interactive: User-friendly but not scriptable

# REPLACED BY: Current argparse-based CLI for balance of features and simplicity
